﻿using System.Diagnostics;
using System.IO;
using System.Reflection;
using System.Text;
using System.Windows;
using System.Windows.Documents;
using System.Xaml;
using DerpingDrivers.Util;
using MahApps.Metro.Controls;
using Markdig;
using Markdig.Wpf;
using Markdown = Markdig.Wpf.Markdown;
using XamlReader = System.Windows.Markup.XamlReader;

namespace DerpingDrivers
{
    /// <summary>
    ///     Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : MetroWindow
    {
        public MainWindow()
        {
            InitializeComponent();

            Loaded += OnLoaded;
        }

        private void OnLoaded(object sender, RoutedEventArgs e)
        {
            SummaryViewer.Pipeline = new MarkdownPipelineBuilder().UseSupportedExtensions().Build();

            SummaryViewer.Markdown = MatchingSummaryContent;
        }

        /// <summary>
        ///     Gets Operating System Architecture display name.
        /// </summary>
        public string OsArchitecture =>
            OsVersionInfo.OsBits == OsVersionInfo.SoftwareArchitecture.Bit64 ? "64-bit" : "32-bit";

        /// <summary>
        ///     Gets Operating System display name.
        /// </summary>
        public string OsVersionName => OsVersionInfo.Name;

        /// <summary>
        ///     Gets Operating System edition name.
        /// </summary>
        public string OsEditionName => string.IsNullOrEmpty(OsVersionInfo.Edition) ? "None" : OsVersionInfo.Edition;

        /// <summary>
        ///     Gets Operating System build number.
        /// </summary>
        public string OsVersion => OsVersionInfo.VersionString;

        /// <summary>
        ///     Gets Boot mode (Legacy BIOS, UEFI).
        /// </summary>
        public string BootMode => UEFIHelper.IsRunningInUEFIMode ? "UEFI" : "Legacy BIOS";

        /// <summary>
        ///     Gets Secure Boot status.
        /// </summary>
        public string SecureBootEnabled => UEFIHelper.IsRunningInUEFIMode
            ? (UEFIHelper.IsSecureBootEnabled ? "Enabled" : "Disabled")
            : "Not available";

        /// <summary>
        ///     Gets OS upgrade status.
        /// </summary>
        public string OsUpgradeStatus =>
            OsUpgradeDetection.IsGrandfathered ? "In-place upgraded" : "Clean installation";

        /// <summary>
        ///     Gets test-mode status.
        /// </summary>
        public string TestSigningStatus => CodeIntegrityHelper.IsTestSignEnabled ? "Enabled" : "Disabled";

        private string MatchingSummaryContent
        {
            get
            {
                if (!CodeIntegrityHelper.IsTestSignEnabled)
                {
                    return Encoding.UTF8.GetString(Properties.Resources.testsigning);
                }

                if (OsVersionInfo.IsWindows10)
                {

                }

                return "*None available*";
            }
        }

        private void Web_OnClick(object sender, RoutedEventArgs e)
        {
            Process.Start("https://vigem.org");
        }

        private void Discord_OnClick(object sender, RoutedEventArgs e)
        {
            Process.Start("https://discord.vigem.org");
        }

        private void Forums_OnClick(object sender, RoutedEventArgs e)
        {
            Process.Start("https://forums.vigem.org");
        }

        private void OpenHyperlink(object sender, System.Windows.Input.ExecutedRoutedEventArgs e)
        {
            Process.Start(e.Parameter.ToString());
        }
    }
}